Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsAuthorized ¶
func IsAuthorized() gin.HandlerFunc
The function IsAuthorized returns a Gin handler function, which is used to process HTTP requests and responses in a Gin web application.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.