utils

package
v0.0.0-...-0d7a5af Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 1, 2023 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CompareHashPassword

func CompareHashPassword(password, hash string) bool

Takes the user input and the hashed the input and compares them. If the hashes match, it returns true.

func GenerateHashPassword

func GenerateHashPassword(password string) (string, error)

Returns a hash value generated from it using a one-way hashing algorithm

func ParseToken

func ParseToken(tokenString string) (claims *models.Claims, err error)

Types

This section is empty.

Jump to