Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CompareHashPassword ¶
Takes the user input and the hashed the input and compares them. If the hashes match, it returns true.
func GenerateHashPassword ¶
Returns a hash value generated from it using a one-way hashing algorithm
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.